package com.chelvc.cloud.maintain.controller;

import java.util.List;
import javax.validation.Valid;

import com.chelvc.cloud.maintain.copier.CategoryCopier;
import com.chelvc.cloud.maintain.vo.CategoryVO;
import com.chelvc.cloud.vehicle.client.CategoryClient;
import com.chelvc.cloud.vehicle.client.dto.CategoryDTO;
import com.chelvc.cloud.vehicle.client.param.CategoryListParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 分类接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CategoryController {
    private final CategoryClient categoryClient;

    /**
     * 获取分类列表
     *
     * @return 分类信息列表
     */
    @PostMapping("/categories")
    public List<CategoryVO> listCategories(@RequestBody @Valid CategoryListParam param) {
        return CategoryCopier.INSTANCE.copying(this.categoryClient.listCategory(param));
    }


    /**
     * 获取分类列表
     *
     * @return 分类信息列表
     */
    @PostMapping("/merchant/getCategories")
    public List<CategoryDTO> getCategories(@RequestBody @Valid CategoryListParam param) {
        return this.categoryClient.getRootCategories(param);
    }

    /**
     * 获取分类列表
     *
     * @return 分类信息列表
     */
    @PostMapping("/getRootCategories")
    public List<CategoryDTO> getRootCategories(@RequestBody @Valid CategoryListParam param) {
        return this.categoryClient.getRootCategories(param);
    }


    /**
     * 获取一级分类列表
     *
     * @return 分类信息列表
     */
    @PostMapping("/getParentCategories")
    public List<CategoryDTO> getParentCategories(@RequestBody @Valid CategoryListParam param) {
        return this.categoryClient.getParentCategories(param);
    }
}
