package com.chelvc.cloud.maintain.controller;

import java.util.List;
import javax.validation.constraints.NotNull;

import com.chelvc.cloud.vehicle.client.CurrencyRecordClient;
import com.chelvc.cloud.vehicle.client.dto.CurrencyRecordDTO;
import com.chelvc.cloud.vehicle.client.dto.EarningsDTO;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 收益记录接口
 *
 * @author liude
 * @date 2023/4/20
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CurrencyRecordController {
    private final CurrencyRecordClient currencyRecordClient;

    /**
     * 用户收益记录列表查询
     *
     * @param type 类型：0-平台；1-用户；2-商户
     */
    @GetMapping("/listCurrencyRecord")
    public List<CurrencyRecordDTO> listCurrencyRecord(@NotNull(message = "查询类型不能为空") Integer type) {
        return this.currencyRecordClient.listCurrencyRecord(type);
    }

    /**
     * 用户获取用户得总收益、本周收益、本月收益、可提现金额
     *
     * @param type 类型：0-平台；1-用户；2-商户
     */
    @GetMapping("/getCurrencyRecord")
    public EarningsDTO getCurrencyRecord(@NotNull(message = "查询类型不能为空") Integer type) {
        return this.currencyRecordClient.getCurrencyRecord(type);
    }
}
