package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.client.DynamicCommentClient;
import com.chelvc.cloud.vehicle.client.dto.DynamicCommentDTO;
import com.chelvc.cloud.vehicle.client.param.AddDynamicCommentParam;
import com.chelvc.cloud.vehicle.client.param.QueryDynamicCommentParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 动态评论
 *
 * @author igl
 * @date 2023-02-25
 */
@Validated
@RestController
@RequestMapping("/client/comment")
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class DynamicCommentController {
    private final DynamicCommentClient dynamicCommentClient;

    /**
     * 查询列表
     *
     * @param param    查询参数
     * @param pageCode
     * @param pageSize
     * @author igl
     * @date 2023/8/9 17:25
     */
    @GetMapping("/page")
    public Pagination<DynamicCommentDTO> list(@Validated QueryDynamicCommentParam param, Integer pageCode,
                                              Integer pageSize) {
        if (pageCode == null) {
            pageCode = 1;
        }
        if (pageSize == null) {
            pageSize = 20;
        }
        return this.dynamicCommentClient.queryPageList(param, pageCode, pageSize);
    }

    /**
     * 新增
     *
     * @param param
     * @author igl
     * @date 2023/8/9 17:25
     */
    @PostMapping("/add")
    public void add(@Validated @RequestBody AddDynamicCommentParam param) {
        this.dynamicCommentClient.insertByBo(param, SessionContextHolder.getId());
    }
}
