package com.chelvc.cloud.maintain.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.FeedbackReplyClient;
import com.chelvc.cloud.vehicle.client.param.FeedBackReplyModifyParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 意见反馈回复接口
 *
 * @author liude
 * @date 2023/1/16
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class FeedbackReplyController {
    private final FeedbackReplyClient feedbackReplyClient;

    /**
     * 新增意见反馈回复
     *
     * @param param 新增参数
     * @return 意见反馈回复主键
     */
    @PostMapping("/feedbackReply")
    public Long addFeedbackReply(@RequestBody @Valid FeedBackReplyModifyParam param) {
        return this.feedbackReplyClient.addFeedbackReply(param);
    }

    /**
     * 修改意见反馈回复
     *
     * @param id    意见反馈主键
     * @param param 修改参数
     */
    @PutMapping("/feedbackReply/{id}")
    public void updateFeedbackReply(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                                    @RequestBody @Valid FeedBackReplyModifyParam param) {
        this.feedbackReplyClient.updateFeedbackReply(id, param);
    }


}
